@@ -50,19 +50,19 @@ struct ethernet_data {
 	struct connman_network *network;
 };
 
-static int cable_probe(struct connman_network *network)
+static int eth_network_probe(struct connman_network *network)
 {
 	DBG("network %p", network);
 
 	return 0;
 }
 
-static void cable_remove(struct connman_network *network)
+static void eth_network_remove(struct connman_network *network)
 {
 	DBG("network %p", network);
 }
 
-static int cable_connect(struct connman_network *network)
+static int eth_network_connect(struct connman_network *network)
 {
 	DBG("network %p", network);
 
@@ -71,7 +71,7 @@ static int cable_connect(struct connman_network *network)
 	return 0;
 }
 
-static int cable_disconnect(struct connman_network *network)
+static int eth_network_disconnect(struct connman_network *network)
 {
 	DBG("network %p", network);
 
@@ -80,13 +80,13 @@ static int cable_disconnect(struct connman_network *network)
 	return 0;
 }
 
-static struct connman_network_driver cable_driver = {
+static struct connman_network_driver eth_network_driver = {
 	.name		= "cable",
 	.type		= CONNMAN_NETWORK_TYPE_ETHERNET,
-	.probe		= cable_probe,
-	.remove		= cable_remove,
-	.connect	= cable_connect,
-	.disconnect	= cable_disconnect,
+	.probe		= eth_network_probe,
+	.remove		= eth_network_remove,
+	.connect	= eth_network_connect,
+	.disconnect	= eth_network_disconnect,
 };
 
 static void add_network(struct connman_device *device,
@@ -163,7 +163,7 @@ static void ethernet_newlink(unsigned flags, unsigned change, void *user_data)
 	ethernet->flags = flags;
 }
 
-static int ethernet_probe(struct connman_device *device)
+static int eth_dev_probe(struct connman_device *device)
 {
 	struct ethernet_data *ethernet;
 
@@ -184,7 +184,7 @@ static int ethernet_probe(struct connman_device *device)
 	return 0;
 }
 
-static void ethernet_remove(struct connman_device *device)
+static void eth_dev_remove(struct connman_device *device)
 {
 	struct ethernet_data *ethernet = connman_device_get_data(device);
 
@@ -199,7 +199,7 @@ static void ethernet_remove(struct connman_device *device)
 	g_free(ethernet);
 }
 
-static int ethernet_enable(struct connman_device *device)
+static int eth_dev_enable(struct connman_device *device)
 {
 	struct ethernet_data *ethernet = connman_device_get_data(device);
 
@@ -208,7 +208,7 @@ static int ethernet_enable(struct connman_device *device)
 	return connman_inet_ifup(ethernet->index);
 }
 
-static int ethernet_disable(struct connman_device *device)
+static int eth_dev_disable(struct connman_device *device)
 {
 	struct ethernet_data *ethernet = connman_device_get_data(device);
 
@@ -217,148 +217,28 @@ static int ethernet_disable(struct connman_device *device)
 	return connman_inet_ifdown(ethernet->index);
 }
 
-static struct connman_device_driver ethernet_driver = {
+static struct connman_device_driver eth_dev_driver = {
 	.name		= "ethernet",
 	.type		= CONNMAN_DEVICE_TYPE_ETHERNET,
-	.probe		= ethernet_probe,
-	.remove		= ethernet_remove,
-	.enable		= ethernet_enable,
-	.disable	= ethernet_disable,
+	.probe		= eth_dev_probe,
+	.remove		= eth_dev_remove,
+	.enable		= eth_dev_enable,
+	.disable	= eth_dev_disable,
 };
 
-static int gadget_probe(struct connman_device *device)
-{
-	DBG("device %p", device);
-	return 0;
-}
-static void gadget_remove(struct connman_device *device)
-{
-	DBG("device %p", device);
-}
-static int gadget_enable(struct connman_device *device)
-{
-	DBG("device %p", device);
-	return 0;
-}
-static int gadget_disable(struct connman_device *device)
-{
-	DBG("device %p", device);
-	return 0;
-}
-
-static struct connman_device_driver gadget_driver = {
-	.name		= "gadget",
-	.type		= CONNMAN_DEVICE_TYPE_GADGET,
-	.probe		= gadget_probe,
-	.remove		= gadget_remove,
-	.enable		= gadget_enable,
-	.disable	= gadget_disable,
-};
-
-static GList *cdc_interface_list = NULL;
-
-static void tech_add_interface(struct connman_technology *technology,
-			int index, const char *name, const char *ident)
-{
-	DBG("index %d name %s ident %s", index, name, ident);
-
-	if (g_list_find(cdc_interface_list, GINT_TO_POINTER((int)index)))
-		return;
-
-	cdc_interface_list = g_list_prepend(cdc_interface_list,
-					(GINT_TO_POINTER((int) index)));
-}
-
-static void tech_remove_interface(struct connman_technology *technology,
-								int index)
-{
-	DBG("index %d", index);
-
-	cdc_interface_list = g_list_remove(cdc_interface_list,
-					GINT_TO_POINTER((int) index));
-}
-
-static void enable_tethering(struct connman_technology *technology,
-						const char *bridge)
-{
-	GList *list;
-
-	for (list = cdc_interface_list; list; list = list->next) {
-		int index = GPOINTER_TO_INT(list->data);
-
-		connman_technology_tethering_notify(technology, true);
-
-		connman_inet_ifup(index);
-
-		connman_inet_add_to_bridge(index, bridge);
-	}
-}
-
-static void disable_tethering(struct connman_technology *technology,
-						const char *bridge)
-{
-	GList *list;
-
-	for (list = cdc_interface_list; list; list = list->next) {
-		int index = GPOINTER_TO_INT(list->data);
-
-		connman_inet_remove_from_bridge(index, bridge);
-
-		connman_inet_ifdown(index);
-
-		connman_technology_tethering_notify(technology, false);
-	}
-}
-
-static int tech_set_tethering(struct connman_technology *technology,
-				const char *identifier, const char *passphrase,
-				const char *bridge, bool enabled)
-{
-	DBG("bridge %s enabled %d", bridge, enabled);
-
-	if (enabled)
-		enable_tethering(technology, bridge);
-	else
-		disable_tethering(technology, bridge);
-
-	return 0;
-}
-
-static int tech_probe(struct connman_technology *technology)
+static int eth_tech_probe(struct connman_technology *technology)
 {
 	return 0;
 }
 
-static void tech_remove(struct connman_technology *technology)
-{
-	g_list_free(cdc_interface_list);
-
-	cdc_interface_list = NULL;
-}
-
-static struct connman_technology_driver tech_driver = {
-	.name			= "cdc_ethernet",
-	.type			= CONNMAN_SERVICE_TYPE_GADGET,
-	.probe			= tech_probe,
-	.remove			= tech_remove,
-	.add_interface		= tech_add_interface,
-	.remove_interface	= tech_remove_interface,
-	.set_tethering		= tech_set_tethering,
-};
-
-static int eth_probe(struct connman_technology *technology)
-{
-	return 0;
-}
-
-static void eth_remove(struct connman_technology *technology)
+static void eth_tech_remove(struct connman_technology *technology)
 {
 	DBG("");
 }
 
 static GList *eth_interface_list = NULL;
 
-static void eth_add_interface(struct connman_technology *technology,
+static void eth_tech_add_interface(struct connman_technology *technology,
 			int index, const char *name, const char *ident)
 {
 	DBG("index %d name %s ident %s", index, name, ident);
@@ -370,7 +250,7 @@ static void eth_add_interface(struct connman_technology *technology,
 					(GINT_TO_POINTER((int) index)));
 }
 
-static void eth_remove_interface(struct connman_technology *technology,
+static void eth_tech_remove_interface(struct connman_technology *technology,
 								int index)
 {
 	DBG("index %d", index);
@@ -379,7 +259,7 @@ static void eth_remove_interface(struct connman_technology *technology,
 					GINT_TO_POINTER((int) index));
 }
 
-static void eth_enable_tethering(struct connman_technology *technology,
+static void eth_tech_enable_tethering(struct connman_technology *technology,
 						const char *bridge)
 {
 	GList *list;
@@ -402,7 +282,7 @@ static void eth_enable_tethering(struct connman_technology *technology,
 	}
 }
 
-static void eth_disable_tethering(struct connman_technology *technology,
+static void eth_tech_disable_tethering(struct connman_technology *technology,
 						const char *bridge)
 {
 	GList *list;
@@ -425,7 +305,7 @@ static void eth_disable_tethering(struct connman_technology *technology,
 	}
 }
 
-static int eth_set_tethering(struct connman_technology *technology,
+static int eth_tech_set_tethering(struct connman_technology *technology,
 				const char *identifier, const char *passphrase,
 				const char *bridge, bool enabled)
 {
@@ -436,53 +316,38 @@ static int eth_set_tethering(struct connman_technology *technology,
 	DBG("bridge %s enabled %d", bridge, enabled);
 
 	if (enabled)
-		eth_enable_tethering(technology, bridge);
+		eth_tech_enable_tethering(technology, bridge);
 	else
-		eth_disable_tethering(technology, bridge);
+		eth_tech_disable_tethering(technology, bridge);
 
 	return 0;
 }
 
-static struct connman_technology_driver eth_driver = {
+static struct connman_technology_driver eth_tech_driver = {
 	.name			= "ethernet",
 	.type			= CONNMAN_SERVICE_TYPE_ETHERNET,
-	.probe			= eth_probe,
-	.remove			= eth_remove,
-	.add_interface		= eth_add_interface,
-	.remove_interface	= eth_remove_interface,
-	.set_tethering		= eth_set_tethering,
+	.probe			= eth_tech_probe,
+	.remove			= eth_tech_remove,
+	.add_interface		= eth_tech_add_interface,
+	.remove_interface	= eth_tech_remove_interface,
+	.set_tethering		= eth_tech_set_tethering,
 };
 
 static int ethernet_init(void)
 {
 	int err;
 
-	err = connman_technology_driver_register(&eth_driver);
+	err = connman_technology_driver_register(&eth_tech_driver);
 	if (err < 0)
 		return err;
 
-	err = connman_network_driver_register(&cable_driver);
+	err = connman_network_driver_register(&eth_network_driver);
 	if (err < 0)
 		return err;
 
-	err = connman_device_driver_register(&ethernet_driver);
+	err = connman_device_driver_register(&eth_dev_driver);
 	if (err < 0) {
-		connman_network_driver_unregister(&cable_driver);
-		return err;
-	}
-
-	err = connman_technology_driver_register(&tech_driver);
-	if (err < 0) {
-		connman_device_driver_unregister(&ethernet_driver);
-		connman_network_driver_unregister(&cable_driver);
-		return err;
-	}
-
-	err = connman_device_driver_register(&gadget_driver);
-	if (err < 0) {
-		connman_technology_driver_unregister(&tech_driver);
-		connman_device_driver_unregister(&ethernet_driver);
-		connman_network_driver_unregister(&cable_driver);
+		connman_network_driver_unregister(&eth_network_driver);
 		return err;
 	}
 
@@ -491,15 +356,11 @@ static int ethernet_init(void)
 
 static void ethernet_exit(void)
 {
-	connman_technology_driver_unregister(&eth_driver);
+	connman_technology_driver_unregister(&eth_tech_driver);
 
-	connman_technology_driver_unregister(&tech_driver);
+	connman_network_driver_unregister(&eth_network_driver);
 
-	connman_network_driver_unregister(&cable_driver);
-
-	connman_device_driver_unregister(&ethernet_driver);
-
-	connman_device_driver_unregister(&gadget_driver);
+	connman_device_driver_unregister(&eth_dev_driver);
 }
 
 CONNMAN_PLUGIN_DEFINE(ethernet, "Ethernet interface plugin", VERSION,
